==> backend-naive-0.1.0-20170902.115513-9.jar: META-INF/leiningen/com.360dialog.orcl/backend-naive/project.clj <==
(defproject com.360dialog.orcl/backend-naive "0.1.0-SNAPSHOT"
  :description "FIXME: write description"
  :url "http://example.com/FIXME"
  :license {:name "Apache License 2.0"
            :url  "http://www.apache.org/licenses/"}
  :dependencies [[org.clojure/clojure "1.8.0"]
                 [org.clojure/clojurescript "1.9.908"]
                 [com.360dialog.orcl/frontend "0.1.0-SNAPSHOT"]
                 [com.360dialog.orcl/testkit "0.1.0-SNAPSHOT"]]
  :cljsbuild {:builds {:dev  {:source-paths ["src/main/clojure"  "src/test/clojure"]
                              :compiler     {:main          orcl.naive
                                             :optimizations :none
                                             :asset-path    "js/out"
                                             :output-to     "resources/public/js/dev.js"
                                             :output-dir    "resources/public/js/out"}
                              :figwheel     true}
                       :test {:source-paths ["src/main/clojure" "src/test/clojure"]
                              :compiler     {:main          orcl.test-runner
                                             :optimizations :none
                                             :output-to     "target/test_js/main.js"}}}}
  :source-paths ["src/main/clojure"]
  :test-paths ["src/test/clojure"]
  :java-source-paths ["src/main/java"]
  :profiles {:dev {:doo          {:build "test"}
                   :dependencies [[criterium "0.4.4"]
                                  [fipp "0.6.9"]
                                  [cheshire "5.7.1"]
                                  [doo "0.1.7"]]
                   :plugins      [[lein-figwheel "0.5.13"]
                                  [lein-doo "0.1.7"]]}})

==> backend-naive-0.1.0-20170925.085117-22.jar: META-INF/leiningen/com.360dialog.orcl/backend-naive/project.clj <==
(defproject com.360dialog.orcl/backend-naive "0.1.0-SNAPSHOT"
  :description "FIXME: write description"
  :url "http://example.com/FIXME"
  :license {:name "Apache License 2.0"
            :url  "http://www.apache.org/licenses/"}
  :dependencies [[org.clojure/clojure "1.8.0"]
                 [org.clojure/clojurescript "1.9.908"]
                 [com.360dialog.orcl/frontend "0.1.0-SNAPSHOT"]
                 [com.360dialog.orcl/testkit "0.1.0-SNAPSHOT"]
                 [org.apache.commons/commons-lang3 "3.6"]]
  :cljsbuild {:builds {:dev  {:source-paths ["src/main/clojure"  "src/test/clojure"]
                              :compiler     {:main          orcl.naive
                                             :optimizations :none
                                             :asset-path    "js/out"
                                             :output-to     "resources/public/js/dev.js"
                                             :output-dir    "resources/public/js/out"}
                              :figwheel     true}
                       :test {:source-paths ["src/main/clojure" "src/test/clojure"]
                              :compiler     {:main          orcl.test-runner
                                             :optimizations :none
                                             :output-to     "target/test_js/main.js"}}}}
  :source-paths ["src/main/clojure"]
  :test-paths ["src/test/clojure"]
  :java-source-paths ["src/main/java"]
  :profiles {:dev {:doo          {:build "test"}
                   :dependencies [[criterium "0.4.4"]
                                  [fipp "0.6.9"]
                                  [cheshire "5.7.1"]
                                  [doo "0.1.7"]]
                   :plugins      [[lein-figwheel "0.5.13"]
                                  [lein-doo "0.1.7"]]}})
